==> components-0.2.0.tgz: package/esm/Atoms/Tabs/TabMenu.js <==
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _templateObject2() {
  var data = _taggedTemplateLiteral(["\n  position: relative;\n  display: flex;\n  flex-direction: column;\n  justify-content: center;\n  align-items: space-between;\n  width: 100%;\n  min-height: 100%;\n\n  @media (max-width: 767px) {\n    & > .hidden {\n      display: ", ";\n    }\n  }\n\n  @media (min-width: 768px) {\n    flex-direction: row;\n    align-items: center;\n  }\n"]);

  _templateObject2 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject() {
  var data = _taggedTemplateLiteral(["\n  display: flex;\n  flex-direction: row;\n  justify-content: center;\n  align-items: center;\n  width: ", ";\n  min-height: ", ";\n  border-bottom: 2px solid ", ";\n  box-sizing: border-box;\n"]);

  _templateObject = function _templateObject() {
    return data;
  };

  return data;
}

function _taggedTemplateLiteral(strings, raw) { if (!raw) { raw = strings.slice(0); } return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import React from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';
var Wrapper = styled.div(_templateObject(), function (props) {
  return props.width;
}, function (props) {
  return props.height;
}, function (props) {
  return props.theme['tabMenuBorderColor'];
});
var Container = styled.div(_templateObject2(), function (props) {
  return props.toggled ? 'flex' : 'none';
});

var TabMenu = function TabMenu(_ref) {
  var children = _ref.children,
      toggled = _ref.toggled,
      rest = _objectWithoutProperties(_ref, ["children", "toggled"]);

  return React.createElement(Wrapper, rest, React.createElement(Container, {
    toggled: toggled
  }, children));
};

TabMenu.propTypes = {
  children: PropTypes.node,
  height: PropTypes.string,
  toggled: PropTypes.bool,
  width: PropTypes.string
};
TabMenu.defaultProps = {
  height: '50px',
  toggled: false,
  width: '100%'
};
export default TabMenu;

==> components-1.1.0.tgz: package/esm/Atoms/Tabs/TabMenu.js <==
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _templateObject2() {
  var data = _taggedTemplateLiteral(["\n  position: relative;\n  display: flex;\n  flex-direction: column;\n  justify-content: center;\n  align-items: space-between;\n  width: 100%;\n  min-height: 100%;\n\n  @media (max-width: 48rem) {\n    & > .disabled {\n      display: ", ";\n    }\n  }\n\n  @media (min-width: 48rem) {\n    flex-direction: row;\n    align-items: center;\n  }\n"]);

  _templateObject2 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject() {
  var data = _taggedTemplateLiteral(["\n  display: flex;\n  flex-direction: row;\n  justify-content: center;\n  align-items: center;\n  width: ", ";\n  min-height: ", ";\n  border-bottom: 0.125rem solid ", ";\n  box-sizing: border-box;\n"]);

  _templateObject = function _templateObject() {
    return data;
  };

  return data;
}

function _taggedTemplateLiteral(strings, raw) { if (!raw) { raw = strings.slice(0); } return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import React from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';
var Wrapper = styled.div(_templateObject(), function (props) {
  return props.width;
}, function (props) {
  return props.height;
}, function (props) {
  return props.theme['tabMenuBorderColor'];
});
var Container = styled.div(_templateObject2(), function (props) {
  return props.toggled ? 'flex' : 'none';
});

var TabMenu = function TabMenu(_ref) {
  var children = _ref.children,
      toggled = _ref.toggled,
      rest = _objectWithoutProperties(_ref, ["children", "toggled"]);

  return React.createElement(Wrapper, rest, React.createElement(Container, {
    toggled: toggled
  }, children));
};

TabMenu.propTypes = {
  children: PropTypes.node,
  height: PropTypes.string,
  toggled: PropTypes.bool,
  width: PropTypes.string
};
TabMenu.defaultProps = {
  height: '3rem',
  toggled: false,
  width: '100%'
};
export default TabMenu;
